%% Bredemeier, Juessen, and Winkler (2022) 
% Journal of Money, Credit and Banking
% This file creates all Figures (1 through 10) of the paper

% install dynare and add its path in line 13

%% housekeeping
clear;
close all;
clc;

%% add dynare path here
addpath('C:/dynare/dynare-4.6.1/matlab')

%% figure settings
set(0,'DefaultAxesFontName','Times');
set(0,'DefaultAxesFontSize',11);
set(0,'DefaultAxesTitleFontWeight','normal')
style_r = '-r';
style_b = '--b';
style_k = '-.k';

%% load data

occ = xlsread('_Data/occupations_employment'); % from IPUMS: emp by occ
ind = xlsread('_Data/industries_employment');  % from IPUMS: emp by ind
emp = xlsread('_Data/FRED-EMP');               % from FRED:  agg emp, sa+nsa

% seasonality
factor = emp(:,1)./emp(:,2); 
occ = occ.*factor; 
ind = ind.*factor;

% calculate percent deviation from February 2020:
occ_mon = occ(3:end,:)./occ(1,:)-1;
ind_mon = ind(3:end,:)./ind(1,:)-1;
occ_mon = occ_mon(:,[3 2 1]); % reshape to order pink blue white

% manual input

employment     = [-14.7 -8.5 -6.5 -6.5];
employment_CBO = 100*[-0.065 -0.0265 -0.0151 -0.0037 0.0069 0.0176];
output         = [-10.1 -3.4-1.828/2 -2.5-1.828*3/4];
output_CBO     = [-2.5-1.828*3/4 -3.264 -1.275 -0.778 -0.412 -0.015 0.313];   

%% regression
hori = 16;

% construct LHS:
y = [log(-ind_mon(:,1)) log(-ind_mon(:,2)) log(-occ_mon(:,1)) log(-occ_mon(:,2)) log(-occ_mon(:,3))];
y = y(:);

% construct RHS:
X = [ones(45,1) repmat((0:8)',5,1) [ones(9,1); zeros(36,1)]  [zeros(9,1); ones(9,1); zeros(27,1)]  [zeros(18,1); ones(9,1); zeros(18,1)]  [zeros(27,1); ones(9,1); zeros(9,1)] [zeros(36,1); ones(9,1)]];

% regression with fixed effects (omitted: distant sector)
indi_RHS = [1:3 5:7];
ball2 = regress(y,X(:,[1:2 3 5:7])); % omitted: distant sector

n1_imp = -100*exp(ball2(1) + ball2(3));
n2_imp = -100*exp(ball2(1) + 0);
nb_imp = -100*exp(ball2(1) + ball2(4));
np_imp = -100*exp(ball2(1) + ball2(5));
nw_imp = -100*exp(ball2(1) + ball2(6));

rho1 = exp(ball2(2));
rho2 = exp(ball2(2));
rhop = exp(ball2(2));
rhob = exp(ball2(2));
rhow = exp(ball2(2));

%% Sector-specific and occupation-specific employment, relative to pre-pandemic, CPS data, April through December

tmin = 0;
tmax = 3;

filename = 'Figure 1';

h=figure('Name',filename,'NumberTitle','off');
subplot(2,2,1)
hold on
title('EMPLOYMENT BY SECTOR')
plot(0:hori,n2_imp*rho2.^([0:hori]*3),'-.k','linewidth',2)
plot(0:hori,n1_imp*rho1.^([0:hori]*3),'-r','linewidth',2)
plot(0:1/3:8/3,ind_mon(:,2)*100,'-dk','linewidth',1,'HandleVisibility','off');
plot(0:1/3:8/3,ind_mon(:,1)*100, '-or','linewidth',1,'HandleVisibility','off');
plot([0 hori],[0 0],'r', 'HandleVisibility','off');
legend('DISTANT','SOCIAL', 'Location','SouthEast')
%xticks([0 4 8 12 16])
xlim([tmin tmax])

subplot(2,2,2)
title('EMPLOYMENT BY OCCUPATION')
hold on
plot(0:hori,nw_imp*rhow.^([0:hori]*3),'-.k','linewidth',2);
plot(0:hori,nb_imp*rhob.^([0:hori]*3),'--b','linewidth',2);
plot(0:hori,np_imp*rhop.^([0:hori]*3),'r','linewidth',2);
plot(0:1/3:8/3,occ_mon(:,3)*100,'-dk','linewidth',1,'HandleVisibility','off');
plot(0:1/3:8/3,occ_mon(:,1)*100, '-ob','linewidth',1,'HandleVisibility','off');
plot(0:1/3:8/3,occ_mon(:,2)*100,'-sr','linewidth',1,'HandleVisibility','off');

plot([0 hori],[0 0],'r', 'HandleVisibility','off');
legend('WHITE-COLLAR','BLUE-COLLAR', 'PINK-COLLAR','Location','SouthEast')
%xticks([0 4 8 12 16])
xlim([tmin tmax])

%% pandemic shock

dynare BJW_model_forec;

aggemp_pan  = (oo_.conditional_forecast.cond.Mean.n_agg(2:end)/h_agg_bar-1)*100;
gdp_pan = (oo_.conditional_forecast.cond.Mean.y(2:end)/gdp_bar-1)*100;
hb_pan=(oo_.conditional_forecast.cond.Mean.nb(2:end)/hb_bar-1)*100;
hp_pan=(oo_.conditional_forecast.cond.Mean.np(2:end)/hp_bar-1)*100;
hw_pan=(oo_.conditional_forecast.cond.Mean.nw(2:end)/hw_bar-1)*100;
h1_pan=(oo_.conditional_forecast.cond.Mean.n1(2:end)/h1_bar-1)*100;
h2_pan=(oo_.conditional_forecast.cond.Mean.n2(2:end)/h2_bar-1)*100;
wed1_pan=(oo_.conditional_forecast.cond.Mean.wed1(2:end));
wed2_pan=(oo_.conditional_forecast.cond.Mean.wed2(2:end));
wedp_pan=(oo_.conditional_forecast.cond.Mean.wedp(2:end));
wedb_pan=(oo_.conditional_forecast.cond.Mean.wedb(2:end));
wedw_pan=(oo_.conditional_forecast.cond.Mean.wedw(2:end));
def_pan=(oo_.conditional_forecast.cond.Mean.def(2:end)-def_bar)/gdp_bar*100;
lip_pan=(oo_.conditional_forecast.cond.Mean.lipp(2:end)/lip_bar-1)*100;
lib_pan=(oo_.conditional_forecast.cond.Mean.libb(2:end)/lib_bar-1)*100;
liw_pan=(oo_.conditional_forecast.cond.Mean.liww(2:end)/liw_bar-1)*100;
lsb_pan=(oo_.conditional_forecast.cond.Mean.lsb(2:end)-lsb_bar)*100;
lsw_pan=(oo_.conditional_forecast.cond.Mean.lsw(2:end)-lsw_bar)*100;
lsp_pan=(oo_.conditional_forecast.cond.Mean.lsp(2:end)-lsp_bar)*100;
 
aggemp_pan_t  = aggemp_pan;
gdp_pan_t = gdp_pan;
hb_pan_t=hb_pan;
hp_pan_t=hp_pan;
hw_pan_t=hw_pan;
h1_pan_t = h1_pan;
h2_pan_t =h2_pan;
def_pan_t =def_pan;
lip_pan_t=lip_pan;
lib_pan_t=lib_pan;
liw_pan_t=liw_pan;
lsp_pan_t=lsp_pan;
lsb_pan_t=lsb_pan;
lsw_pan_t=lsw_pan;

gin_lip_pan=oo_.conditional_forecast.cond.Mean.lipp(2:end);
gin_lib_pan=oo_.conditional_forecast.cond.Mean.libb(2:end);
gin_liw_pan=oo_.conditional_forecast.cond.Mean.liww(2:end);

%% Figure: wedges

hori = 13;
set(0,'DefaultAxesFontName','Times');
set(0,'DefaultAxesFontSize',11);

filename = 'Figure 2';

h=figure('Name',filename,'NumberTitle','off');
set(gcf, 'PaperPosition', [0.63 0.63 19.72 28.41/2]);

subplot(2,2,4)
hold on
plot(0:hori-1,wedb_pan(1:hori,1),style_b,'linewidth',2);
plot(0:hori-1,wedp_pan(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,wedw_pan(1:hori,1),style_k,'linewidth',2);
legend('BLUE-COLLAR', 'PINK-COLLAR', 'WHITE-COLLAR','Location','NorthEast')
title('WEDGES BY OCCUPATION')
xticks([0 4 8 12])
xlim([0 9])
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');

subplot(2,2,3)
hold on
plot(0:hori-1,wed1_pan(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,wed2_pan(1:hori,1),style_k,'linewidth',2)
legend('SOCIAL', 'DISTANT','Location','NorthEast')
title('WEDGES BY SECTOR')
xticks([0 4 8 12])
xlim([0 9])
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');

%% Figure: Pandemic shock

hori = 23;

style_r = '-r';
style_b = '--b';
style_k = '-.k';

filename = 'Figure 3';

h=figure('Name',filename,'NumberTitle','off');
set(gcf, 'PaperPosition', [0.63 0.63 19.72 28.41/2]);
set(gca, 'Layer', 'top');
subplot(2,2,1)
hold on
plot(0:hori-1,def_pan_t(1:hori,1),style_k,'linewidth',2)
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');
xticks([0 4 8 12])
xlim([0 9])
title('BUDGET DEFICIT')

subplot(2,2,2)
hold on
plot(0:hori-1,gdp_pan_t(1:hori,1),style_k,'linewidth',2)
plot(0:hori-1,aggemp_pan_t(1:hori,1),style_r,'linewidth',2)

plot(0:2,output,'--k','linewidth',1,'MarkerSize',4)
plot([2 3:4:23],output_CBO,':k','linewidth',1,'HandleVisibility','off')
plot(0:3,employment,'--r','linewidth',1)
plot(3:4:23,employment_CBO,':r','linewidth',1,'HandleVisibility','off')
legend('OUTPUT','EMPLOYMENT','OUTPUT (data)','EMPLOYMENT (data)','Location', 'SouthEast');
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');
xticks([0 4 8 12 16])
xlim([0 9])
title('OUTPUT AND EMPLOYMENT')

subplot(2,2,4)
hold on
plot(0:hori-1,hb_pan_t(1:hori,1),style_b,'linewidth',2)
plot(0:hori-1,hp_pan_t(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,hw_pan_t(1:hori,1),style_k,'linewidth',2);
legend('BLUE-COLLAR', 'PINK-COLLAR', 'WHITE-COLLAR','Location','SouthEast')
title('EMPLOYMENT BY OCCUPATION')
xticks([0 4 8 12])
xlim([0 9])
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');

subplot(2,2,3)
hold on
plot(0:hori-1,h1_pan_t(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,h2_pan_t(1:hori,1),style_k,'linewidth',2)
legend('SOCIAL', 'DISTANT','Location','SouthEast')
title('EMPLOYMENT BY SECTOR')
xticks([0 4 8 12])
xlim([0 9])
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');

%% Government spending

sigma_tax  = [1 1];
sigma_matG = [1 -0.0685]; 

dynare BJW_model_rev;

spending_g = g_eps_g/y_bar*100;
spending1_g=g1_eps_g/y_bar*100;
spending2_g=g2_eps_g/y_bar*100;
aggemp_g  = n_agg_eps_g/h_agg_bar*100;
gdp_g = y_eps_g/gdp_bar*100;
hb_g=nb_eps_g/hb_bar*100;
hp_g=np_eps_g/hp_bar*100;
hw_g=nw_eps_g/hw_bar*100;
h1_g = n1_eps_g/h1_bar*100;
h2_g = n2_eps_g/h2_bar*100;
def_g = def_eps_g/gdp_bar*100;
lib_g=libb_eps_g;
lip_g=lipp_eps_g;
liw_g=liww_eps_g;
lsb_g=lsb_eps_g*100;
lsp_g=lsp_eps_g*100;
lsw_g=lsw_eps_g*100;

ts=4;
A=zeros(ts,1);
scalingA=-aggemp_g(3)/aggemp_pan(ts+3);
scalingG=scalingA;
spending_g_ts = [A; spending_g(1:end-length(A))/scalingA];
spending1_g_ts = [A; spending1_g(1:end-length(A))/scalingA];
spending2_g_ts = [A; spending2_g(1:end-length(A))/scalingA];
aggemp_g_ts  = [A;aggemp_g(1:end-length(A))/scalingA];
gdp_g_ts = [A;gdp_g(1:end-length(A))/scalingA];
hb_g_ts=[A;hb_g(1:end-length(A))/scalingA];
hp_g_ts=[A;hp_g(1:end-length(A))/scalingA];
hw_g_ts=[A;hw_g(1:end-length(A))/scalingA];
h1_g_ts =[A;h1_g(1:end-length(A))/scalingA];
h2_g_ts =[A;h2_g(1:end-length(A))/scalingA];
def_g_ts =[A;def_g(1:end-length(A))/scalingA];
lib_g_ts=[A;lib_g(1:end-length(A))/scalingA];
lip_g_ts=[A;lip_g(1:end-length(A))/scalingA];
liw_g_ts=[A;liw_g(1:end-length(A))/scalingA];
lsb_g_ts=[A;lsb_g(1:end-length(A))/scalingA];
lsp_g_ts=[A;lsp_g(1:end-length(A))/scalingA];
lsw_g_ts=[A;lsw_g(1:end-length(A))/scalingA];

lip_pan_g = gin_lip_pan + lip_g_ts;
lib_pan_g = gin_lib_pan + lib_g_ts;
liw_pan_g = gin_liw_pan + liw_g_ts;

%% Figure: Pandemic shock + G stimulus
filename = 'Figure 4';

h=figure('Name',filename,'NumberTitle','off');
set(gcf, 'PaperPosition', [0.63 0.63 19.72 28.41/2]);
set(gca, 'Layer', 'top');
subplot(2,2,1)
hold on
plot(0:hori-1,def_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,zeros(hori,1),'-.b','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,zeros(hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,def_pan_t(1:hori,1)+def_g_ts(1:hori,1),style_k,'linewidth',2)
plot(0:hori-1,spending1_g_ts(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,spending2_g_ts(1:hori,1),'-b','linewidth',2)
xticks([0 4 8 12])
xlim([3 12])
legend('DEFICIT','G_{social}', 'G_{distant}','Location', 'NorthEast');
title('FISCAL POLICY')

subplot(2,2,2)
hold on
plot(0:hori-1,aggemp_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,gdp_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,gdp_pan_t(1:hori,1)+gdp_g_ts(1:hori,1),style_k,'linewidth',2)
plot(0:hori-1,aggemp_pan_t(1:hori,1)+aggemp_g_ts(1:hori,1),style_r,'linewidth',2)
xticks([0 4 8 12])
xlim([3 12])
legend('OUTPUT','EMPLOYMENT','Location', 'SouthEast');
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');
title('OUTPUT AND EMPLOYMENT')

subplot(2,2,4)
hold on
plot(0:hori-1,hb_pan_t(1:hori,1),'--b','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hp_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hw_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hb_pan_t(1:hori,1)+hb_g_ts(1:hori,1),style_b,'linewidth',2)
plot(0:hori-1,hp_pan_t(1:hori,1)+hp_g_ts(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,hw_pan_t(1:hori,1)+hw_g_ts(1:hori,1),style_k,'linewidth',2);
xticks([0 4 8 12])
xlim([3 12])
legend('BLUE-COLLAR', 'PINK-COLLAR', 'WHITE-COLLAR','Location','SouthEast')
title('EMPLOYMENT BY OCCUPATION')
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');


subplot(2,2,3)
hold on
plot(0:hori-1,h1_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,h2_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,h1_pan_t(1:hori,1)+h1_g_ts(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,h2_pan_t(1:hori,1)+h2_g_ts(1:hori,1),style_k,'linewidth',2)
xticks([0 4 8 12])
xlim([3 12])
legend('SOCIAL', 'DISTANT','Location','SouthEast')
title('EMPLOYMENT BY SECTOR')
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');

%% Tax

tax_tau = tau_eps_tau*100;
aggemp_tau  = n_agg_eps_tau/h_agg_bar*100;
gdp_tau = y_eps_tau/gdp_bar*100;
hb_tau=nb_eps_tau/hb_bar*100;
hp_tau=np_eps_tau/hp_bar*100;
hw_tau=nw_eps_tau/hw_bar*100;
h1_tau = n1_eps_tau/h1_bar*100;
h2_tau = n2_eps_tau/h2_bar*100;
def_tau = def_eps_tau/gdp_bar*100;
lib_tau=libb_eps_tau;
lip_tau=lipp_eps_tau;
liw_tau=liww_eps_tau;
lsb_tau=lsb_eps_tau*100;
lsp_tau=lsp_eps_tau*100;
lsw_tau=lsw_eps_tau*100;

scalingA=-aggemp_tau(3)/aggemp_pan(ts+3);
scalingtau=scalingA;
tax_tau_ts = [A; tax_tau(1:end-length(A))/scalingA];
aggemp_tau_ts  = [A;aggemp_tau(1:end-length(A))/scalingA];
gdp_tau_ts = [A;gdp_tau(1:end-length(A))/scalingA];
hb_tau_ts=[A;hb_tau(1:end-length(A))/scalingA];
hp_tau_ts=[A;hp_tau(1:end-length(A))/scalingA];
hw_tau_ts=[A;hw_tau(1:end-length(A))/scalingA];
h1_tau_ts =[A;h1_tau(1:end-length(A))/scalingA];
h2_tau_ts =[A;h2_tau(1:end-length(A))/scalingA];
def_tau_ts =[A;def_tau(1:end-length(A))/scalingA];
lib_tau_ts=[A;lib_tau(1:end-length(A))/scalingA];
lip_tau_ts=[A;lip_tau(1:end-length(A))/scalingA];
liw_tau_ts=[A;liw_tau(1:end-length(A))/scalingA];
lsb_tau_ts=[A;lsb_tau(1:end-length(A))/scalingA];
lsp_tau_ts=[A;lsp_tau(1:end-length(A))/scalingA];
lsw_tau_ts=[A;lsw_tau(1:end-length(A))/scalingA];

lip_pan_tau = gin_lip_pan + lip_tau_ts;
lib_pan_tau = gin_lib_pan + lib_tau_ts;
liw_pan_tau = gin_liw_pan + liw_tau_ts;

%% Figure: Pandemic shock + tau stimulus
filename = 'Figure 7';

h=figure('Name',filename,'NumberTitle','off');
set(gcf, 'PaperPosition', [0.63 0.63 19.72 28.41/2]);
set(gca, 'Layer', 'top');
subplot(2,2,1)
hold on
plot(0:hori-1,def_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,zeros(hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,def_pan_t(1:hori,1)+def_tau_ts(1:hori,1),style_k,'linewidth',2)
plot(0:hori-1,tax_tau_ts(1:hori,1),'-s ','linewidth',2)
plot(0:hori-1,tax_tau_ts(1:hori,1),'-r *','linewidth',1)
xticks([0 4 8 12])
xlim([3 12])
legend('DEFICIT','LABOR TAX','CAPITAL TAX','Location', 'NorthEast');
title('FISCAL POLICY')

subplot(2,2,2)
hold on
plot(0:hori-1,aggemp_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,gdp_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,gdp_pan_t(1:hori,1)+gdp_tau_ts(1:hori,1),style_k,'linewidth',2)
plot(0:hori-1,aggemp_pan_t(1:hori,1)+aggemp_tau_ts(1:hori,1),style_r,'linewidth',2)
xticks([0 4 8 12])
xlim([3 12])
legend('OUTPUT','EMPLOYMENT','Location', 'SouthEast');
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');
title('OUTPUT AND EMPLOYMENT')

subplot(2,2,4)
hold on
plot(0:hori-1,hb_pan_t(1:hori,1),'--b','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hp_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hw_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hb_pan_t(1:hori,1)+hb_tau_ts(1:hori,1),style_b,'linewidth',2)
plot(0:hori-1,hp_pan_t(1:hori,1)+hp_tau_ts(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,hw_pan_t(1:hori,1)+hw_tau_ts(1:hori,1),style_k,'linewidth',2);
legend('BLUE-COLLAR', 'PINK-COLLAR', 'WHITE-COLLAR','Location','SouthEast')
xticks([0 4 8 12])
xlim([3 12])
title('EMPLOYMENT BY OCCUPATION')
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');


subplot(2,2,3)
hold on
plot(0:hori-1,h1_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,h2_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,h1_pan_t(1:hori,1)+h1_tau_ts(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,h2_pan_t(1:hori,1)+h2_tau_ts(1:hori,1),style_k,'linewidth',2)
xticks([0 4 8 12])
xlim([3 12])
legend('SOCIAL', 'DISTANT','Location','SouthEast')
title('EMPLOYMENT BY SECTOR')
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');

%% Labor tax shock
sigma_tax=[1 0]; 
sigma_matG=[1 0]; 

dynare BJW_model_rev;

tax_taul = tau_eps_tau*100;
aggemp_taul = n_agg_eps_tau/h_agg_bar*100;
gdp_taul = y_eps_tau/gdp_bar*100;
hb_taul=nb_eps_tau/hb_bar*100;
hp_taul=np_eps_tau/hp_bar*100;
hw_taul=nw_eps_tau/hw_bar*100;
h1_taul = n1_eps_tau/h1_bar*100;
h2_taul = n2_eps_tau/h2_bar*100;
def_taul = def_eps_tau/gdp_bar*100;
lib_taul=libb_eps_tau;
lip_taul=lipp_eps_tau;
liw_taul=liww_eps_tau;
lsb_taul=lsb_eps_tau*100;
lsp_taul=lsp_eps_tau*100;
lsw_taul=lsw_eps_tau*100;

scalingA=-aggemp_taul(3)/aggemp_pan(ts+3);
scaling_taul=scalingA;
tax_taul_ts = [A; tax_taul(1:end-length(A))/scalingA];
aggemp_taul_ts  = [A;aggemp_taul(1:end-length(A))/scalingA];
gdp_taul_ts = [A;gdp_taul(1:end-length(A))/scalingA];
hb_taul_ts=[A;hb_taul(1:end-length(A))/scalingA];
hp_taul_ts=[A;hp_taul(1:end-length(A))/scalingA];
hw_taul_ts=[A;hw_taul(1:end-length(A))/scalingA];
h1_taul_ts =[A;h1_taul(1:end-length(A))/scalingA];
h2_taul_ts =[A;h2_taul(1:end-length(A))/scalingA];
def_taul_ts =[A;def_taul(1:end-length(A))/scalingA];
lib_taul_ts=[A;lib_taul(1:end-length(A))/scalingA];
lip_taul_ts=[A;lip_taul(1:end-length(A))/scalingA];
liw_taul_ts=[A;liw_taul(1:end-length(A))/scalingA];
lsb_taul_ts=[A;lsb_taul(1:end-length(A))/scalingA];
lsp_taul_ts=[A;lsp_taul(1:end-length(A))/scalingA];
lsw_taul_ts=[A;lsw_taul(1:end-length(A))/scalingA];

lip_pan_taul = gin_lip_pan + lip_taul_ts;
lib_pan_taul = gin_lib_pan + lib_taul_ts;
liw_pan_taul = gin_liw_pan + liw_taul_ts;

%% Figure: Pandemic shock + taul stimulus
filename = 'Figure 8';

h=figure('Name',filename,'NumberTitle','off');
set(gcf, 'PaperPosition', [0.63 0.63 19.72 28.41/2]);
set(gca, 'Layer', 'top');
subplot(2,2,1)
hold on
plot(0:hori-1,def_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,zeros(hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,def_pan_t(1:hori,1)+def_taul_ts(1:hori,1),style_k,'linewidth',2)
plot(0:hori-1,tax_taul_ts(1:hori,1),style_r,'linewidth',2)
xticks([0 4 8 12])
xlim([3 12])
legend('DEFICIT','LABOR TAX','Location', 'NorthEast');
title('FISCAL POLICY')

subplot(2,2,2)
hold on
plot(0:hori-1,aggemp_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,gdp_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,gdp_pan_t(1:hori,1)+gdp_taul_ts(1:hori,1),style_k,'linewidth',2)
plot(0:hori-1,aggemp_pan_t(1:hori,1)+aggemp_taul_ts(1:hori,1),style_r,'linewidth',2)
xticks([0 4 8 12])
xlim([3 12])
legend('OUTPUT','EMPLOYMENT','Location', 'SouthEast');
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');
title('OUTPUT AND EMPLOYMENT')

subplot(2,2,4)
hold on
plot(0:hori-1,hb_pan_t(1:hori,1),'--b','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hp_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hw_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hb_pan_t(1:hori,1)+hb_taul_ts(1:hori,1),style_b,'linewidth',2)
plot(0:hori-1,hp_pan_t(1:hori,1)+hp_taul_ts(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,hw_pan_t(1:hori,1)+hw_taul_ts(1:hori,1),style_k,'linewidth',2);
xticks([0 4 8 12])
xlim([3 12])
legend('BLUE-COLLAR', 'PINK-COLLAR', 'WHITE-COLLAR','Location','SouthEast')
title('EMPLOYMENT BY OCCUPATION')
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');

subplot(2,2,3)
hold on
plot(0:hori-1,h1_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,h2_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,h1_pan_t(1:hori,1)+h1_taul_ts(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,h2_pan_t(1:hori,1)+h2_taul_ts(1:hori,1),style_k,'linewidth',2)
xticks([0 4 8 12])
xlim([3 12])
legend('SOCIAL', 'DISTANT','Location','SouthEast')
title('EMPLOYMENT BY SECTOR')
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');

%% Capital tax shock
sigma_tau=0;
sigma_tauk=1;
sigma_tax=[sigma_tau sigma_tauk];
sigma_matG=[1 0];

dynare BJW_model_rev;

tax_tauk = tauk_eps_tau*100;
aggemp_tauk = n_agg_eps_tau/h_agg_bar*100;
gdp_tauk = y_eps_tau/gdp_bar*100;
hb_tauk=nb_eps_tau/hb_bar*100;
hp_tauk=np_eps_tau/hp_bar*100;
hw_tauk=nw_eps_tau/hw_bar*100;
h1_tauk = n1_eps_tau/h1_bar*100;
h2_tauk = n2_eps_tau/h2_bar*100;
def_tauk = def_eps_tau/gdp_bar*100;
lib_tauk=libb_eps_tau;
lip_tauk=lipp_eps_tau;
liw_tauk=liww_eps_tau;
lsb_tauk=lsb_eps_tau*100;
lsp_tauk=lsp_eps_tau*100;
lsw_tauk=lsw_eps_tau*100;

scalingA=-aggemp_tauk(3)/aggemp_pan(ts+3);
scalingtauk=scalingA;
tax_tauk_ts = [A; tax_tauk(1:end-length(A))/scalingA];
aggemp_tauk_ts  = [A;aggemp_tauk(1:end-length(A))/scalingA];
gdp_tauk_ts = [A;gdp_tauk(1:end-length(A))/scalingA];
hb_tauk_ts=[A;hb_tauk(1:end-length(A))/scalingA];
hp_tauk_ts=[A;hp_tauk(1:end-length(A))/scalingA];
hw_tauk_ts=[A;hw_tauk(1:end-length(A))/scalingA];
h1_tauk_ts =[A;h1_tauk(1:end-length(A))/scalingA];
h2_tauk_ts =[A;h2_tauk(1:end-length(A))/scalingA];
def_tauk_ts =[A;def_tauk(1:end-length(A))/scalingA];
lib_tauk_ts=[A;lib_tauk(1:end-length(A))/scaling_taul];
lip_tauk_ts=[A;lip_tauk(1:end-length(A))/scaling_taul];
liw_tauk_ts=[A;liw_tauk(1:end-length(A))/scaling_taul];
lsb_tauk_ts=[A;lsb_tauk(1:end-length(A))/scaling_taul];
lsp_tauk_ts=[A;lsp_tauk(1:end-length(A))/scaling_taul];
lsw_tauk_ts=[A;lsw_tauk(1:end-length(A))/scaling_taul];

lip_pan_tauk = gin_lip_pan + lip_tauk_ts;
lib_pan_tauk = gin_lib_pan + lib_tauk_ts;
liw_pan_tauk = gin_liw_pan + liw_tauk_ts;
 

%% Figure: Pandemic shock + tauk stimulus
filename = 'Figure 9';

h=figure('Name',filename,'NumberTitle','off');
set(gcf, 'PaperPosition', [0.63 0.63 19.72 28.41/2]);
set(gca, 'Layer', 'top');
subplot(2,2,1)
hold on
plot(0:hori-1,def_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,zeros(hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,def_pan_t(1:hori,1)+def_tauk_ts(1:hori,1)*scalingA/scaling_taul,style_k,'linewidth',2)
plot(0:hori-1,tax_tauk_ts(1:hori,1)*scalingA/scaling_taul,style_r,'linewidth',2)
xticks([0 4 8 12])
xlim([3 12])
legend('DEFICIT','CAPITAL TAX','Location', 'SouthEast');
title('FISCAL POLICY')

subplot(2,2,2)
hold on
plot(0:hori-1,aggemp_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,gdp_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,gdp_pan_t(1:hori,1)+gdp_tau_ts(1:hori,1)*scalingA/scaling_taul,style_k,'linewidth',2)
plot(0:hori-1,aggemp_pan_t(1:hori,1)+aggemp_tau_ts(1:hori,1)*scalingA/scaling_taul,style_r,'linewidth',2)
xticks([0 4 8 12])
xlim([3 12])
legend('OUTPUT','EMPLOYMENT','Location', 'SouthEast');
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');
title('OUTPUT AND EMPLOYMENT')

subplot(2,2,4)
hold on
plot(0:hori-1,hb_pan_t(1:hori,1),'--b','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hp_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hw_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hb_pan_t(1:hori,1)+hb_tauk_ts(1:hori,1)*scalingA/scaling_taul,style_b,'linewidth',2)
plot(0:hori-1,hp_pan_t(1:hori,1)+hp_tauk_ts(1:hori,1)*scalingA/scaling_taul,style_r,'linewidth',2)
plot(0:hori-1,hw_pan_t(1:hori,1)+hw_tauk_ts(1:hori,1)*scalingA/scaling_taul,style_k,'linewidth',2);
xticks([0 4 8 12])
xlim([3 12])
legend('BLUE-COLLAR', 'PINK-COLLAR', 'WHITE-COLLAR','Location','SouthEast')
title('EMPLOYMENT BY OCCUPATION')
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');


subplot(2,2,3)
hold on
plot(0:hori-1,h1_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,h2_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,h1_pan_t(1:hori,1)+h1_tauk_ts(1:hori,1)*scalingA/scaling_taul,style_r,'linewidth',2)
plot(0:hori-1,h2_pan_t(1:hori,1)+h2_tauk_ts(1:hori,1)*scalingA/scaling_taul,style_k,'linewidth',2)
xticks([0 4 8 12])
xlim([3 12])
legend('SOCIAL', 'DISTANT','Location','SouthEast')
title('EMPLOYMENT BY SECTOR')
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');


%% G1 spending

sigma_tau=0;
sigma_tauk=0;
sigma_tax=[sigma_tau sigma_tauk];
sigma_matG=[1 0.23106]; 

dynare BJW_model_rev;

spending_g1 = g_eps_g/y_bar*100;
spending1_g1 = g1_eps_g/y_bar*100;
spending2_g1 = g2_eps_g/y_bar*100;
aggemp_g1  = n_agg_eps_g/h_agg_bar*100;
gdp_g1 = y_eps_g/gdp_bar*100;
hb_g1=nb_eps_g/hb_bar*100;
hp_g1=np_eps_g/hp_bar*100;
hw_g1=nw_eps_g/hw_bar*100;
h1_g1 = n1_eps_g/h1_bar*100;
h2_g1 = n2_eps_g/h2_bar*100;
def_g1 = def_eps_g/gdp_bar*100;
lib_g1=libb_eps_g;
lip_g1=lipp_eps_g;
liw_g1=liww_eps_g;
lsb_g1=lsb_eps_g*100;
lsp_g1=lsp_eps_g*100;
lsw_g1=lsw_eps_g*100;

scalingA=-aggemp_g1(3)/aggemp_pan(ts+3);
scalingG1=scalingA;
spending_g1_ts = [A; spending_g1(1:end-length(A))/scalingA];
spending1_g1_ts = [A; spending1_g1(1:end-length(A))/scalingA];
spending2_g1_ts = [A; spending2_g1(1:end-length(A))/scalingA];
aggemp_g1_ts  = [A;aggemp_g1(1:end-length(A))/scalingA];
gdp_g1_ts = [A;gdp_g1(1:end-length(A))/scalingA];
hb_g1_ts=[A;hb_g1(1:end-length(A))/scalingA];
hp_g1_ts=[A;hp_g1(1:end-length(A))/scalingA];
hw_g1_ts=[A;hw_g1(1:end-length(A))/scalingA];
h1_g1_ts =[A;h1_g1(1:end-length(A))/scalingA];
h2_g1_ts =[A;h2_g1(1:end-length(A))/scalingA];
def_g1_ts =[A;def_g1(1:end-length(A))/scalingA];
lib_g1_ts=[A;lib_g1(1:end-length(A))/scalingA];
lip_g1_ts=[A;lip_g1(1:end-length(A))/scalingA];
liw_g1_ts=[A;liw_g1(1:end-length(A))/scalingA];
lsb_g1_ts=[A;lsb_g1(1:end-length(A))/scalingA];
lsp_g1_ts=[A;lsp_g1(1:end-length(A))/scalingA];
lsw_g1_ts=[A;lsw_g1(1:end-length(A))/scalingA];

lip_pan_g1 = gin_lip_pan + lip_g1_ts;
lib_pan_g1 = gin_lib_pan + lib_g1_ts;
liw_pan_g1 = gin_liw_pan + liw_g1_ts;

%% Figure: Pandemic shock + G1 stimulus
filename = 'Figure 5';

h=figure('Name',filename,'NumberTitle','off');
set(gcf, 'PaperPosition', [0.63 0.63 19.72 28.41/2]);
set(gca, 'Layer', 'top');
subplot(2,2,1)
hold on
plot(0:hori-1,def_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,zeros(hori,1),'-.b','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,zeros(hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,def_pan_t(1:hori,1)+def_g1_ts(1:hori,1),style_k,'linewidth',2)
plot(0:hori-1,spending1_g1_ts(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,spending2_g1_ts(1:hori,1),'-b','linewidth',2)
xticks([0 4 8 12])
xlim([3 12])
legend('DEFICIT','G_{social}', 'G_{distant}','Location', 'NorthEast');
title('FISCAL POLICY')

subplot(2,2,2)
hold on
plot(0:hori-1,aggemp_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,gdp_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,gdp_pan_t(1:hori,1)+gdp_g1_ts(1:hori,1),style_k,'linewidth',2)
plot(0:hori-1,aggemp_pan_t(1:hori,1)+aggemp_g1_ts(1:hori,1),style_r,'linewidth',2)
xticks([0 4 8 12])
xlim([3 12])
legend('OUTPUT','EMPLOYMENT','Location', 'SouthEast');
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');
title('OUTPUT AND EMPLOYMENT')

subplot(2,2,4)
hold on
plot(0:hori-1,hb_pan_t(1:hori,1),'--b','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hp_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hw_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hb_pan_t(1:hori,1)+hb_g1_ts(1:hori,1),style_b,'linewidth',2)
plot(0:hori-1,hp_pan_t(1:hori,1)+hp_g1_ts(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,hw_pan_t(1:hori,1)+hw_g1_ts(1:hori,1),style_k,'linewidth',2);
xticks([0 4 8 12])
xlim([3 12])
legend('BLUE-COLLAR', 'PINK-COLLAR', 'WHITE-COLLAR','Location','SouthEast')
title('EMPLOYMENT BY OCCUPATION')
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');


subplot(2,2,3)
hold on
plot(0:hori-1,h1_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,h2_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,h1_pan_t(1:hori,1)+h1_g1_ts(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,h2_pan_t(1:hori,1)+h2_g1_ts(1:hori,1),style_k,'linewidth',2)
xticks([0 4 8 12])
xlim([3 12])
legend('SOCIAL', 'DISTANT','Location','SouthEast')
title('EMPLOYMENT BY SECTOR')
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');


%% G2 spending
sigma_tau=0;
sigma_tauk=0;
sigma_tax=[sigma_tau sigma_tauk];
sigma_matG=[1 -0.368279];

dynare BJW_model_rev;

spending_g2 = g_eps_g/y_bar*100;
spending1_g2 = g1_eps_g/y_bar*100;
spending2_g2 = g2_eps_g/y_bar*100;
aggemp_g2  = n_agg_eps_g/h_agg_bar*100;
gdp_g2 = y_eps_g/gdp_bar*100;
hb_g2=nb_eps_g/hb_bar*100;
hp_g2=np_eps_g/hp_bar*100;
hw_g2=nw_eps_g/hw_bar*100;
h1_g2 = n1_eps_g/h1_bar*100;
h2_g2 = n2_eps_g/h2_bar*100;
def_g2 = def_eps_g/gdp_bar*100;
lib_g2=libb_eps_g;
lip_g2=lipp_eps_g;
liw_g2=liww_eps_g;
lsb_g2=lsb_eps_g*100;
lsp_g2=lsp_eps_g*100;
lsw_g2=lsw_eps_g*100;

scalingA=-aggemp_g2(3)/aggemp_pan(ts+3);
scalingG2=scalingA;
spending_g2_ts = [A; spending_g2(1:end-length(A))/scalingA];
spending1_g2_ts = [A; spending1_g2(1:end-length(A))/scalingA];
spending2_g2_ts = [A; spending2_g2(1:end-length(A))/scalingA];
aggemp_g2_ts  = [A;aggemp_g2(1:end-length(A))/scalingA];
gdp_g2_ts = [A;gdp_g2(1:end-length(A))/scalingA];
hb_g2_ts=[A;hb_g2(1:end-length(A))/scalingA];
hp_g2_ts=[A;hp_g2(1:end-length(A))/scalingA];
hw_g2_ts=[A;hw_g2(1:end-length(A))/scalingA];
h1_g2_ts =[A;h1_g2(1:end-length(A))/scalingA];
h2_g2_ts =[A;h2_g2(1:end-length(A))/scalingA];
def_g2_ts =[A;def_g2(1:end-length(A))/scalingA];
lib_g2_ts=[A;lib_g2(1:end-length(A))/scalingA];
lip_g2_ts=[A;lip_g2(1:end-length(A))/scalingA];
liw_g2_ts=[A;liw_g2(1:end-length(A))/scalingA];
lsb_g2_ts=[A;lsb_g2(1:end-length(A))/scalingA];
lsp_g2_ts=[A;lsp_g2(1:end-length(A))/scalingA];
lsw_g2_ts=[A;lsw_g2(1:end-length(A))/scalingA];

lip_pan_g2 = gin_lip_pan + lip_g2_ts;
lib_pan_g2 = gin_lib_pan + lib_g2_ts;
liw_pan_g2 = gin_liw_pan + liw_g2_ts;

%% Figure: Pandemic shock + G2 stimulus
filename = 'Figure 6';

h=figure('Name',filename,'NumberTitle','off');
set(gcf, 'PaperPosition', [0.63 0.63 19.72 28.41/2]);
set(gca, 'Layer', 'top');
subplot(2,2,1)
hold on
plot(0:hori-1,def_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,zeros(hori,1),'-.b','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,zeros(hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,def_pan_t(1:hori,1)+def_g2_ts(1:hori,1),style_k,'linewidth',2)
plot(0:hori-1,spending1_g2_ts(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,spending2_g2_ts(1:hori,1),'-b','linewidth',2)
xticks([0 4 8 12])
xlim([3 12])
legend('DEFICIT','G_{social}', 'G_{distant}','Location', 'NorthEast');
title('FISCAL POLICY')

subplot(2,2,2)
hold on
plot(0:hori-1,aggemp_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,gdp_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,gdp_pan_t(1:hori,1)+gdp_g2_ts(1:hori,1),style_k,'linewidth',2)
plot(0:hori-1,aggemp_pan_t(1:hori,1)+aggemp_g2_ts(1:hori,1),style_r,'linewidth',2)
xticks([0 4 8 12])
xlim([3 12])
legend('OUTPUT','EMPLOYMENT','Location', 'SouthEast');
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');
title('OUTPUT AND EMPLOYMENT')

subplot(2,2,4)
hold on
plot(0:hori-1,hb_pan_t(1:hori,1),'--b','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hp_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hw_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,hb_pan_t(1:hori,1)+hb_g2_ts(1:hori,1),style_b,'linewidth',2)
plot(0:hori-1,hp_pan_t(1:hori,1)+hp_g2_ts(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,hw_pan_t(1:hori,1)+hw_g2_ts(1:hori,1),style_k,'linewidth',2);
xticks([0 4 8 12])
xlim([3 12])
legend('BLUE-COLLAR', 'PINK-COLLAR', 'WHITE-COLLAR','Location','SouthEast')
title('EMPLOYMENT BY OCCUPATION')
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');

subplot(2,2,3)
hold on
plot(0:hori-1,h1_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,h2_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off')
plot(0:hori-1,h1_pan_t(1:hori,1)+h1_g2_ts(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,h2_pan_t(1:hori,1)+h2_g2_ts(1:hori,1),style_k,'linewidth',2)
xticks([0 4 8 12])
xlim([3 12])
legend('SOCIAL', 'DISTANT','Location','SouthEast')
title('EMPLOYMENT BY SECTOR')
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');


%% Figure: Distributional consequences of the pandemic

filename = 'Figure 10a';

h=figure('Name',filename,'NumberTitle','off');
set(gcf, 'PaperPosition', [0.63 0.63 19.72 28.41/2]);
set(gca, 'Layer', 'top');
subplot(2,2,1)
hold on
plot(0:hori-1,lib_pan_t(1:hori,1),style_b,'linewidth',2)
plot(0:hori-1,lip_pan_t(1:hori,1),style_r,'linewidth',2)
plot(0:hori-1,liw_pan_t(1:hori,1),style_k,'linewidth',2);
legend('BLUE-COLLAR', 'PINK-COLLAR', 'WHITE-COLLAR','Location','SouthEast')
xticks([0 4 8 12])
xlim([0 12])
title('EARNINGS BY OCCUPATION')
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');

subplot(2,2,2)
hold on
plot(0:hori-1,lsb_pan_t(1:hori,1),style_b,'linewidth',2)
plot(0:hori-1,lsp_pan_t(1:hori,1),style_r,'linewidth',2)
legend('BLUE-COLLAR', 'PINK-COLLAR','Location','SouthEast')
xticks([0 4 8 12])
xlim([0 12])
title('SHARES IN TOTAL EARNINGS')
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');


%% Distributional consequences of symmetric spending expansion

filename = 'Figure 10b';

h=figure('Name',filename,'NumberTitle','off');
set(gcf, 'PaperPosition', [0.63 0.63 19.72 28.41/2]);
set(gca, 'Layer', 'top');
subplot(2,2,1)
hold on
plot(0:hori-1,lib_pan_t(1:hori,1),'--b','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,lip_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,liw_pan_t(1:hori,1),'--k','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,(lib_pan_g(1:hori,1)/lib_bar-1)*100,style_b,'linewidth',2)
plot(0:hori-1,(lip_pan_g(1:hori,1)/lip_bar-1)*100,style_r,'linewidth',2)
plot(0:hori-1,(liw_pan_g(1:hori,1)/liw_bar-1)*100,style_k,'linewidth',2);
legend('BLUE-COLLAR', 'PINK-COLLAR', 'WHITE-COLLAR','Location','SouthEast')
xticks([4 8 12])
xlim([3 12])
title('EARNINGS BY OCCUPATION')
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');

subplot(2,2,2)
hold on
plot(0:hori-1,lsb_pan_t(1:hori,1),'--b','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,lsp_pan_t(1:hori,1),'--r','linewidth',1,'HandleVisibility','off');
plot(0:hori-1,lsb_pan_t(1:hori,1)+lsb_g_ts(1:hori,1),style_b,'linewidth',2)
plot(0:hori-1,lsp_pan_t(1:hori,1)+lsp_g_ts(1:hori,1),style_r,'linewidth',2)
legend('BLUE-COLLAR', 'PINK-COLLAR','Location','SouthEast')
xticks([4 8 12])
xlim([3 12])
title('SHARES IN TOTAL EARNINGS')
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');

%% Blue-collar share in total labor income for different fiscal measures.

filename = 'Figure 10c';
h=figure('Name',filename,'NumberTitle','off');
set(gcf, 'PaperPosition', [0.63 0.63 19.72 28.41/2]);
set(gca, 'Layer', 'top');
subplot(2,2,[1 2])
hold on
plot(0:hori-1,lsb_pan_t(1:hori,1),'--k','linewidth',1);
plot(0:hori-1,lsb_pan_t(1:hori,1)+lsb_g_ts(1:hori,1),style_r,'linewidth',2,'MarkerSize',4);
plot(0:hori-1,lsb_pan_t(1:hori,1)+lsb_g1_ts(1:hori,1),style_k,'linewidth',2,'MarkerSize',4);
plot(0:hori-1,lsb_pan_t(1:hori,1)+lsb_g2_ts(1:hori,1),style_b,'linewidth',2,'MarkerSize',4);
plot(0:hori-1,lsb_pan_t(1:hori,1)+lsb_tau_ts(1:hori,1),[style_r 'd'],'linewidth',2,'MarkerSize',4);
plot(0:hori-1,lsb_pan_t(1:hori,1)+lsb_taul_ts(1:hori,1),[style_k 'o'],'linewidth',2,'MarkerSize',4);
plot(0:hori-1,lsb_pan_t(1:hori,1)+lsb_tauk_ts(1:hori,1),[style_b 'x'],'linewidth',2,'MarkerSize',4);
legend('Pandemic','G','G_{social}','G_{distant}','\tau^{n}=\tau^{k}','\tau^n','\tau^k','Location','EastOutside')
xticks([4 8 12])
xlim([3 12])
title('BLUE-COLLAR SHARE IN TOTAL EARNINGS')
plot([0 hori-1],[0 0],'r', 'HandleVisibility','off');
